@@ -100,10 +100,14 @@ Reference
    :members:
 """
 
-import sys, numpy as np
+from __future__ import with_statement
+
+import sys
+import warnings
+import numpy as np
 
 from guidata.qt.QtGui import (QMenu, QListWidget, QListWidgetItem, QVBoxLayout,
-                              QToolBar, QMessageBox, QBrush)
+                              QToolBar, QMessageBox, QBrush, QColor, QPen, QPolygonF)
 from guidata.qt.QtCore import (Qt, QPoint, QPointF, QLineF, SIGNAL, QRectF,
                                QLine)
 
@@ -126,6 +130,27 @@ from guiqwt.signals import (SIG_ACTIVE_ITEM_CHANGED, SIG_ITEMS_CHANGED,
                             SIG_ITEM_REMOVED, SIG_AXIS_DIRECTION_CHANGED,
                             SIG_PLOT_AXIS_CHANGED)
 
+def _simplify_poly(pts, off, scale, bounds):
+    ax, bx, ay, by = scale
+    xm, ym, xM, yM = bounds
+    a = np.array( [[ax,ay]] )
+    b = np.array( [[bx,by]] )
+    _pts = a*pts+b
+    poly = []
+    NP = off.shape[0]
+    for i in xrange(off.shape[0]):
+        i0 = off[i,1]
+        if i+1<NP:
+            i1 = off[i+1,1]
+        else:
+            i1 = pts.shape[0]
+        poly.append( (_pts[i0:i1], i) )
+    return poly
+
+try:
+    from gshhs import simplify_poly
+except ImportError:
+    simplify_poly = _simplify_poly
 
 def seg_dist(P, P0, P1):
     """
@@ -542,9 +567,228 @@ class CurveItem(QwtPlotCurve):
 assert_interfaces_valid(CurveItem)
 
 
-def _transform(map,v):
-    return QwtScaleMap.transform(map,v)
-vmap = np.vectorize(_transform)
+class PolygonMapItem(QwtPlotItem):
+    """
+    Construct a curve `plot item` with the parameters *curveparam*
+    (see :py:class:`guiqwt.styles.CurveParam`)
+    """
+    __implements__ = (IBasePlotItem,)
+    
+    _readonly = False
+    _private = False
+    _can_select = False
+    _can_resize = False
+    _can_move = False
+    _can_rotate = False
+
+    def __init__(self, curveparam=None):
+        super(PolygonMapItem, self).__init__()
+        if curveparam is None:
+            self.curveparam = CurveParam(_("PolygonMap"), icon='curve.png')
+        else:
+            self.curveparam = curveparam
+        self.selected = False
+        self.immutable = True # set to false to allow moving points around
+        self._pts = None # Array of points Mx2
+        self._n = None   # Array of polygon offsets/ends Nx1 (polygon k points are _pts[_n[k-1]:_n[k]])
+        self._c = None   # Color of polygon Nx2 [border,background] as RGBA uint32
+        self.update_params()
+        
+    def types(self):
+        return (ICurveItemType, ITrackableItemType, ISerializableType)
+
+    def can_select(self):
+        return self._can_select
+    def can_resize(self):
+        return self._can_resize
+    def can_rotate(self):
+        return self._can_rotate
+    def can_move(self):
+        return self._can_move
+    def set_selectable(self, state):
+        """Set item selectable state"""
+        self._can_select = state
+    def set_resizable(self, state):
+        """Set item resizable state
+        (or any action triggered when moving an handle, e.g. rotation)"""
+        self._can_resize = state
+    def set_movable(self, state):
+        """Set item movable state"""
+        self._can_move = state
+    def set_rotatable(self, state):
+        """Set item rotatable state"""
+        self._can_rotate = state
+
+    def setPen(self, x):
+        pass
+    def setBrush(self,x):
+        pass
+    def setSymbol(self,x):
+        pass
+    def setCurveAttribute(self,x,y):
+        pass
+    def setStyle(self,x):
+        pass
+    def setCurveType(self,x):
+        pass
+    def setBaseline(self,x):
+        pass
+    def __reduce__(self):
+        state = (self.curveparam, self._pts, self._n, self._c, self.z())
+        res = ( PolygonMapItem, (), state )
+        return res
+
+    def __setstate__(self, state):
+        param, pts, n, c, z = state
+        self.curveparam = param
+        self.set_data(pts, n, c)
+        self.setZ(z)
+        self.update_params()
+
+    def set_readonly(self, state):
+        """Set object readonly state"""
+        self._readonly = state
+        
+    def is_readonly(self):
+        """Return object readonly state"""
+        return self._readonly
+        
+    def set_private(self, state):
+        """Set object as private"""
+        self._private = state
+        
+    def is_private(self):
+        """Return True if object is private"""
+        return self._private
+
+    def invalidate_plot(self):
+        plot = self.plot()
+        if plot is not None:
+            plot.invalidate()
+
+    def select(self):
+        """Select item"""
+        self.selected = True
+        self.setSymbol(SELECTED_SYMBOL)
+        self.invalidate_plot()
+    
+    def unselect(self):
+        """Unselect item"""
+        self.selected = False
+        # Restoring initial curve parameters:
+        self.curveparam.update_curve(self)
+        self.invalidate_plot()
+
+    def get_data(self):
+        """Return curve data x, y (NumPy arrays)"""
+        return self._pts, self._n, self._c
+
+    def set_data(self, pts, n, c):
+        """
+        Set curve data:
+            * x: NumPy array
+            * y: NumPy array
+        """
+        self._pts = np.array(pts, copy=False)
+        self._n = np.array(n, copy=False)
+        self._c = np.array(c, copy=False)
+        xmin, ymin = self._pts.min(axis=0)
+        xmax, ymax = self._pts.max(axis=0)
+        self.bounds = QRectF(xmin,ymin,xmax-xmin,ymax-ymin)
+        
+    def is_empty(self):
+        """Return True if item data is empty"""
+        return self._pts is None or self._pts.size == 0
+
+    def hit_test(self, pos):
+        """Calcul de la distance d'un point à une courbe
+        renvoie (dist, handle, inside)"""
+        if self.is_empty():
+            return sys.maxint, 0, False, None
+        plot = self.plot()
+        # TODO
+        return distance, i, False, None
+    
+    def get_closest_coordinates(self, x, y):
+        """Renvoie les coordonnées (x',y') du point le plus proche de (x,y)
+        Méthode surchargée pour ErrorBarSignalCurve pour renvoyer
+        les coordonnées des pointes des barres d'erreur"""
+        # TODO
+        return x, y
+
+    def get_coordinates_label(self, xc, yc):
+        title = self.title().text()
+        return "%s:<br>x = %f<br>y = %f" % (title, xc, yc)
+
+    def move_local_point_to(self, handle, pos, ctrl=None):
+        return
+
+    def move_local_shape(self, old_pos, new_pos):
+        pass
+
+    def move_with_selection(self, delta_x, delta_y):
+        pass
+
+    def update_params(self):
+        self.curveparam.update_curve(self)
+        if self.selected:
+            self.select()
+
+    def get_item_parameters(self, itemparams):
+        itemparams.add("CurveParam", self, self.curveparam)
+    
+    def set_item_parameters(self, itemparams):
+        update_dataset(self.curveparam, itemparams.get("CurveParam"),
+                       visible_only=True)
+        self.update_params()
+
+    def draw(self, painter, xMap, yMap, canvasRect):
+        from time import time
+        p1x = xMap.p1()
+        s1x = xMap.s1()
+        ax = (xMap.p2() - p1x)/(xMap.s2()-s1x)
+        p1y = yMap.p1()
+        s1y = yMap.s1()
+        ay = (yMap.p2() - p1y)/(yMap.s2()-s1y)
+        bx, by = p1x-s1x*ax, p1y-s1y*ay
+        _c = self._c
+        _n = self._n
+        fgcol = QColor()
+        bgcol = QColor()
+        #t0 = time()
+        polygons = simplify_poly(self._pts, _n, (ax, bx, ay, by),
+                                 canvasRect.getCoords() )
+        #t1 = time()
+        #print len(polygons), t1-t0
+        #t2 = time()
+        for poly, num in polygons:
+            points = []
+            for i in xrange(poly.shape[0]):
+                points.append(QPointF(poly[i,0],poly[i,1]))
+            pg = QPolygonF(points)
+            fgcol.setRgba(int(_c[num,0]))
+            bgcol.setRgba(int(_c[num,1]))
+            painter.setPen(QPen(fgcol))
+            painter.setBrush(QBrush(bgcol))
+            painter.drawPolygon(pg)
+        #print "poly:", time()-t2
+        
+    def boundingRect(self):
+        return self.bounds
+
+assert_interfaces_valid(PolygonMapItem)
+
+
+def _transform(map, v):
+    return QwtScaleMap.transform(map, v)
+def vmap(map, v):
+    """Transform coordinates while handling RuntimeWarning 
+    that could be raised by NumPy when trying to transform 
+    a zero in logarithmic scale for example"""
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore", category=RuntimeWarning)
+        output = np.vectorize(_transform)(map, v)
+    return output
 
 class ErrorBarCurveItem(CurveItem):
     """
@@ -561,6 +805,7 @@ class ErrorBarCurveItem(CurveItem):
         super(ErrorBarCurveItem, self).__init__(curveparam)
         self._dx = None
         self._dy = None
+        self._minmaxarrays = {}
         
     def unselect(self):
         """Unselect item"""
@@ -596,25 +841,43 @@ class ErrorBarCurveItem(CurveItem):
                 dy = None
         self._dx = dx
         self._dy = dy
+        self._minmaxarrays = {}
 
-    def get_minmax_arrays(self):
-        x = self._x
-        y = self._y
-        dx = self._dx
-        dy = self._dy
-        if dx is None:
-            xmin = x
-            xmax = x
-        else:
-            xmin = x - dx
-            xmax = x + dx
-        if dy is None:
-            ymin = y
-            ymax = y
-        else:
-            ymin = y - dy
-            ymax = y + dy
-        return xmin, xmax, ymin, ymax
+    def get_minmax_arrays(self, all_values=True):
+        if self._minmaxarrays.get(all_values) is None:
+            x = self._x
+            y = self._y
+            dx = self._dx
+            dy = self._dy
+            if all_values:
+                if dx is None:
+                    xmin = xmax = x
+                else:
+                    xmin, xmax = x - dx, x + dx
+                if dy is None:
+                    ymin = ymax = y
+                else:
+                    ymin, ymax = y - dy, y + dy
+                self._minmaxarrays.setdefault(all_values,
+                                              (xmin, xmax, ymin, ymax))
+            else:
+                isf = np.logical_and(np.isfinite(x), np.isfinite(y))
+                if dx is not None:
+                    isf = np.logical_and(isf, np.isfinite(dx))
+                if dy is not None:
+                    isf = np.logical_and(isf, np.isfinite(dy))
+                if dx is None:
+                    xmin = xmax = x[isf]
+                else:
+                    xmin, xmax = x[isf] - dx[isf], x[isf] + dx[isf]
+                if dy is None:
+                    ymin = ymax = y[isf]
+                else:
+                    ymin, ymax = y[isf] - dy[isf], y[isf] + dy[isf]
+                self._minmaxarrays.setdefault(all_values,
+                                              (x[isf], y[isf],
+                                               xmin, xmax, ymin, ymax))
+        return self._minmaxarrays[all_values]
         
     def get_closest_coordinates(self, x, y):
         # Surcharge d'une méthode de base de CurveItem
@@ -656,13 +919,11 @@ class ErrorBarCurveItem(CurveItem):
         return QRectF(xmin, ymin, xmaxf.max()-xmin, ymaxf.max()-ymin)
         
     def draw(self, painter, xMap, yMap, canvasRect):
-        x = self._x
-        if x is None or x.size == 0:
+        if self._x is None or self._x.size == 0:
             return
-        y = self._y
+        x, y, xmin, xmax, ymin, ymax = self.get_minmax_arrays(all_values=False)
         tx = vmap(xMap, x)
         ty = vmap(yMap, y)
-        xmin, xmax, ymin, ymax = self.get_minmax_arrays()
         RN = xrange(len(tx))
         if self.errorOnTop:
             QwtPlotCurve.draw(self, painter, xMap, yMap, canvasRect)
@@ -714,7 +975,7 @@ class ErrorBarCurveItem(CurveItem):
                     xi = tx[i]
                     points.append(QPoint(xi, tymin[i]))
                     rpoints.append(QPoint(xi, tymax[i]))
-                points+=reversed(rpoints)
+                points += reversed(rpoints)
                 painter.setBrush(QBrush(self.errorBrush))
                 painter.drawPolygon(*points)
 
@@ -1007,7 +1268,7 @@ class CurvePlot(BasePlot):
         * axes_synchronised: keep all x and y axes synchronised when zomming or
                              panning
     """
-    AUTOSCALE_TYPES = (CurveItem,)
+    AUTOSCALE_TYPES = (CurveItem,PolygonMapItem)
     def __init__(self, parent=None, title=None, xlabel=None, ylabel=None,
                  xunit=None, yunit=None, gridparam=None,
                  section="plot", axes_synchronised=False):
@@ -1300,16 +1561,16 @@ class CurvePlot(BasePlot):
         if replot:
             self.replot()
 
-    def set_axis_limits(self, axis_id, vmin, vmax):
+    def set_axis_limits(self, axis_id, vmin, vmax, stepsize=0):
         """Set axis limits (minimum and maximum values)"""
         axis_id = self.get_axis_id(axis_id)
         vmin, vmax = sorted([vmin, vmax])
         if self.get_axis_direction(axis_id):
-            BasePlot.set_axis_limits(self, axis_id, vmax, vmin)
+            BasePlot.set_axis_limits(self, axis_id, vmax, vmin, stepsize)
         else:
-            BasePlot.set_axis_limits(self, axis_id, vmin, vmax)
-            
-    #---- Public API -----------------------------------------------------------    
+            BasePlot.set_axis_limits(self, axis_id, vmin, vmax, stepsize)
+
+    #---- Public API -----------------------------------------------------------
     def get_axis_direction(self, axis_id):
         """
         Return axis direction of increasing values
@@ -1421,4 +1682,4 @@ class CurvePlot(BasePlot):
         x0, x1 = self.get_axis_limits(xaxis)
         y0, y1 = self.get_axis_limits(yaxis)
         return x0, x1, y0, y1
-        
\ No newline at end of file
+
