@@ -133,7 +133,11 @@ IMAGE_LOAD_FILTERS = '%s (*.png *.jpg *.gif *.tif *.tiff)\n'\
                      % (_(u"Images"), _(u"NumPy arrays"), _(u"Text files"))
 IMAGE_SAVE_FILTERS = IMAGE_LOAD_FILTERS
 try:
+    import logging
+    logger = logging.getLogger("pydicom")
+    logger.setLevel(logging.CRITICAL)
     import dicom
+    logger.setLevel(logging.WARNING)
     IMAGE_LOAD_FILTERS += ('\n%s (*.dcm)' % _(u"DICOM images"))
 except ImportError:
     pass
@@ -278,10 +282,13 @@ def array_to_dicomfile(arr, dcmstruct, filename, dtype=None, max_range=False):
     dcmstruct.BitsStored = infos.bits
     dcmstruct.HighBit = infos.bits-1
     dcmstruct.PixelRepresentation = ('u', 'i').index(infos.kind)
+    data_vr = ('US', 'SS')[dcmstruct.PixelRepresentation]
     dcmstruct.Rows = arr.shape[0]
     dcmstruct.Columns = arr.shape[1]
     dcmstruct.SmallestImagePixelValue = int(arr.min())
+    dcmstruct[0x00280106].VR = data_vr
     dcmstruct.LargestImagePixelValue = int(arr.max())
+    dcmstruct[0x00280107].VR = data_vr
     if not dcmstruct.PhotometricInterpretation.startswith('MONOCHROME'):
         dcmstruct.PhotometricInterpretation = 'MONOCHROME1'
     dcmstruct.PixelData = arr.tostring()
